@@ -5,16 +5,16 @@
 
 
 import subprocess
-import commands
 
-from base import *
+from .base import *
 
 
 def copy(string):
     """Copy given string into system clipboard."""
     try:
-        subprocess.Popen(['pbcopy'], stdin=subprocess.PIPE).communicate(str(unicode(string)))
-    except Exception, why:
+        subprocess.Popen(['pbcopy'], stdin=subprocess.PIPE).communicate(
+                string.encode("utf-8"))
+    except OSError as why:
         raise XcodeNotFound
     
     return
@@ -23,7 +23,7 @@ def copy(string):
 def paste():
     """Returns system clipboard contents."""
     try:
-        return unicode(commands.getoutput('pbpaste'))
-    except Exception, why:
+        return subprocess.check_output('pbpaste').decode("utf-8")
+    except OSError as why:
         raise XcodeNotFound
-    
\ No newline at end of file
+    
